@@ -21,7 +21,7 @@ use File::Spec;
 use File::Copy;
 use Rex::Repositorio::Repository_Factory;
 
-our $VERSION = "0.0.2";
+our $VERSION = "0.1.0";
 
 has config => ( is => 'ro' );
 has logger => ( is => 'ro' );
@@ -273,176 +273,6 @@ sub tag {
   }
 }
 
-sub download_gzip {
-  my ( $self, $url ) = @_;
-
-  my $content = $self->download($url);
-
-  require Compress::Zlib;
-
-  $self->logger->debug("Starting uncompressing of: $url");
-
-  my $un_content = Compress::Zlib::memGunzip($content);
-  $self->logger->debug("Finished uncompressing of: $url");
-  if ( !$un_content ) {
-    $self->logger->error("Error uncompressing data.");
-    confess "Error uncompressing data.";
-  }
-
-  return $un_content;
-}
-
-sub download {
-  my ( $self, $url ) = @_;
-
-  $self->logger->debug("Starting download of: $url");
-  my $resp = $self->ua->get($url);
-  $self->logger->debug("Finished download of: $url");
-
-  if ( !$resp->is_success ) {
-    $self->logger->error("Can't download $url.");
-    $self->logger->error( "Status: " . $resp->status_line );
-    confess "Error downloading $url.";
-  }
-
-  return $resp->content;
-}
-
-sub get_xml {
-  my ( $self, $xml ) = @_;
-  return XML::LibXML->load_xml( string => $xml );
-}
-
-sub decode_xml {
-  my ( $self, $xml ) = @_;
-  return XMLin( $xml, ForceArray => 1 );
-}
-
-sub download_package {
-  my $self   = shift;
-  my %option = validate(
-    @_,
-    {
-      name => {
-        type => SCALAR
-      },
-      url => {
-        type => SCALAR
-      },
-      dest => {
-        type => SCALAR
-      },
-      cb => {
-        type     => CODEREF,
-        optional => 1,
-      },
-      force => {
-        type     => BOOLEAN,
-        optional => 1,
-      }
-    }
-  );
-
-  my $package_file = $self->config->{RepositoryRoot} . "/head/" . $option{dest};
-  $self->_download_binary_file(
-    dest  => $package_file,
-    url   => $option{url},
-    cb    => $option{cb},
-    force => $option{force},
-  );
-}
-
-sub download_metadata {
-  my $self   = shift;
-  my %option = validate(
-    @_,
-    {
-      url => {
-        type => SCALAR
-      },
-      dest => {
-        type => SCALAR
-      },
-      cb => {
-        type     => CODEREF,
-        optional => 1,
-      },
-      force => {
-        type     => BOOLEAN,
-        optional => 1,
-      }
-    }
-  );
-
-  my $metadata_file =
-    $self->config->{RepositoryRoot} . "/head/" . $option{dest};
-  $self->_download_binary_file(
-    dest  => $metadata_file,
-    url   => $option{url},
-    cb    => $option{cb},
-    force => $option{force},
-  );
-}
-
-sub _download_binary_file {
-  my $self   = shift;
-  my %option = validate(
-    @_,
-    {
-      url => {
-        type => SCALAR
-      },
-      dest => {
-        type => SCALAR
-      },
-      cb => {
-        type     => CODEREF | UNDEF,
-        optional => 1,
-      },
-      force => {
-        type => BOOLEAN
-      }
-    }
-  );
-
-  $self->logger->debug("Downloading: $option{url} -> $option{dest}");
-
-  mkpath( dirname( $option{dest} ) ) if ( !-d dirname $option{dest} );
-
-  if ( -f $option{dest} && !$option{force} ) {
-    $self->logger->debug("Skipping $option{url}. File aready exists.");
-    return;
-  }
-
-  if ( !-w dirname( $option{dest} ) ) {
-    $self->logger->error( "Can't write to " . dirname( $option{dest} ) );
-    confess "Can't write to " . dirname( $option{dest} );
-  }
-
-  if ( -f $option{dest} && $option{force} ) {
-    unlink $option{dest};
-  }
-
-  open my $fh, ">", $option{dest};
-  binmode $fh;
-  my $resp = $self->ua->get(
-    $option{url},
-    ':content_cb' => sub {
-      my ( $data, $response, $protocol ) = @_;
-      print $fh $data;
-    }
-  );
-  close $fh;
-
-  if ( !$resp->is_success ) {
-    $self->logger->error("Can't download $option{url}.");
-    $self->logger->error( "Status: " . $resp->status_line );
-    confess "Error downloading $option{url}.";
-  }
-
-  $option{cb}->( $option{dest} ) if ( exists $option{cb} && $option{cb} );
-}
-
 sub get_repo_dir {
   my $self   = shift;
   my %option = validate(
@@ -459,57 +289,6 @@ sub get_repo_dir {
       . $self->config->{Repository}->{ $option{repo} }->{local} );
 }
 
-sub add_file_to_repo {
-  my $self   = shift;
-  my %option = validate(
-    @_,
-    {
-      source => {
-        type => SCALAR
-      },
-      dest => {
-        type => SCALAR
-      }
-    }
-  );
-
-  if ( !-f $option{source} ) {
-    $self->logger->error("Fild $option{source} not found.");
-    confess "Fild $option{source} not found.";
-  }
-
-  $self->logger->debug("Copy $option{source} -> $option{dest}");
-  my $ret = copy $option{source}, $option{dest};
-  if ( !$ret ) {
-    $self->logger->error("Error copying file $option{source} to $option{dest}");
-    confess "Error copying file $option{source} to $option{dest}";
-  }
-}
-
-sub remove_file_from_repo {
-  my $self   = shift;
-  my %option = validate(
-    @_,
-    {
-      file => {
-        type => SCALAR
-      }
-    }
-  );
-
-  if ( !-f $option{file} ) {
-    $self->logger->error("Fild $option{file} not found.");
-    confess "Fild $option{file} not found.";
-  }
-
-  $self->logger->debug("Deleting $option{file}.");
-  my $ret = unlink $option{file};
-  if ( !$ret ) {
-    $self->logger->error("Error deleting file $option{file}");
-    confess "Error deleting file $option{file}";
-  }
-}
-
 sub _print {
   my $self  = shift;
   my @lines = @_;
@@ -601,12 +380,12 @@ create consistant installations of your server.
 To configure repositor.io create a configuration file
 I</etc/rex/repositorio.conf>.
  RepositoryRoot = /srv/html/repo/
-    
+   
  # log4perl configuration file
  <Log4perl>
    config = /etc/rex/io/log4perl.conf
  </Log4perl>
-    
+   
  # create a mirror of the nightly rex repository
  # the files will be stored in
  # /srv/html/repo/head/rex-centos-6-x86-64/CentOS/6/rex/x86_64/
@@ -615,7 +394,7 @@ I</etc/rex/repositorio.conf>.
    local = rex-centos-6-x86-64/CentOS/6/rex/x86_64/
    type  = Yum
  </Repository>
-    
+   
  # create a mirror of centos 6
  # and download the pxe boot files, too.
  <Repository centos-6-x86-64>
@@ -624,17 +403,26 @@ I</etc/rex/repositorio.conf>.
    type   = Yum
    images = true
  </Repository>
-    
+   
  # create a custom repository
  <Repository centos-6-x86-64-mixed>
    local = centos-6-x86-64-mixed/mixed/6/x86_64/
    type  = Yum
  </Repository>
-
+   
+ <Repository debian-wheezy-i386-main>
+   url       = http://ftp.de.debian.org/debian/
+   local     = debian-wheezy-amd64-main/debian
+   type      = Apt
+   arch      = i386
+   dist      = wheezy
+   component = main
+ </Repository>
+ 
 An example log4perl.conf file:
 
  log4perl.rootLogger                    = DEBUG, FileAppndr1
-   
+
  log4perl.appender.FileAppndr1          = Log::Log4perl::Appender::File
  log4perl.appender.FileAppndr1.filename = /var/log/repositorio.log
  log4perl.appender.FileAppndr1.layout   = Log::Log4perl::Layout::SimpleLayout
